var LinkedList = /** @class */ (function () {
    function LinkedList() {
        this.first = null;
        this.length = 0;
    }
    LinkedList.prototype.push = function (v) {
        this.first = { value: v, next: this.first };
        this.length++;
    };
    LinkedList.prototype.unshift = function () {
        if (this.length === 0) {
            return;
        }
        else {
            var lastnode = this.first;
            var bforelast = lastnode;
            while (lastnode.next !== null) {
                bforelast = lastnode;
                lastnode = lastnode.next;
            }
            if (bforelast === this.first) {
                // bforelast is equal to this.first in case this list had a length of
                // 1 before calling unshift
                this.first = null;
            }
            bforelast.next = null;
            this.length--;
            return lastnode.value;
        }
    };
    return LinkedList;
}());
var OrderedMap = /** @class */ (function () {
    function OrderedMap() {
        this.map = new Map();
        this.order = new LinkedList();
    }
    Object.defineProperty(OrderedMap.prototype, "length", {
        get: function () {
            return this.order.length;
        },
        enumerable: true,
        configurable: true
    });
    OrderedMap.prototype.has = function (key) {
        return this.map.has(key);
    };
    OrderedMap.prototype.get = function (key) {
        return this.map.get(key);
    };
    OrderedMap.prototype.set = function (key, value) {
        if (this.has(key)) {
            // in case key already exists we just update associated value
            this.map.set(key, value);
            return;
        }
        this.map.set(key, value);
        this.order.push(key);
    };
    OrderedMap.prototype.unshift = function () {
        var oldestkey = this.order.unshift();
        if (oldestkey !== undefined) {
            this.map.delete(oldestkey);
        }
    };
    return OrderedMap;
}());
var Cache = /** @class */ (function () {
    function Cache(maxsize) {
        this.map = new OrderedMap();
        this.maxsize = maxsize;
    }
    Cache.prototype.has = function (key) {
        return this.map.has(key);
    };
    Cache.prototype.get = function (key) {
        return this.map.get(key);
    };
    Object.defineProperty(Cache.prototype, "length", {
        get: function () {
            return this.map.length;
        },
        enumerable: true,
        configurable: true
    });
    Cache.prototype.set = function (key, value) {
        this.map.set(key, value);
        if (this.map.length > this.maxsize) {
            this.map.unshift();
        }
    };
    return Cache;
}());
function memoize(func, maxsize) {
    if (maxsize === void 0) { maxsize = 50; }
    // memoize function `func`. `func` should be a function with arity of 1
    var memory = new Cache(maxsize);
    return function (arg1) {
        if (memory.has(arg1)) {
            return memory.get(arg1);
        }
        else {
            var result = func(arg1);
            memory.set(arg1, result);
            return result;
        }
    };
}

export { Cache, LinkedList, memoize };
