import Vue from 'vue';
import { memoize } from './memoize.js';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var ColorNames;
(function (ColorNames) {
    ColorNames[ColorNames["primary"] = 0] = "primary";
    ColorNames[ColorNames["secondary"] = 1] = "secondary";
    ColorNames[ColorNames["textLight"] = 2] = "textLight";
    ColorNames[ColorNames["default"] = 3] = "default";
    ColorNames[ColorNames["success"] = 4] = "success";
    ColorNames[ColorNames["info"] = 5] = "info";
    ColorNames[ColorNames["error"] = 6] = "error";
    ColorNames[ColorNames["warning"] = 7] = "warning";
})(ColorNames || (ColorNames = {}));
var defaultColors = {
    primary: "pink-500",
    secondary: "green-500",
    textLight: "orange-400",
    default: "black",
    success: "green-500",
    info: "blue-500",
    error: "red-500",
    warning: "orange-500"
};
// filter because typescript will generate object from enum with
// numerical keys
var COLOR_NAME_KEYS = Object.keys(ColorNames).filter(function (c) { return !/\d+/.test(c); });
var plugin = {
    install: function (Vue$1, opts) {
        if (Vue !== Vue$1) {
            console.error("Multiple instances of Vue detected\nSee https://github.com/vuetifyjs/vuetify/issues/4068\n\nIf you're seeing \"$attrs is readonly\", it's caused by this");
        }
        var prefix = "";
        var colors = __assign({}, defaultColors);
        if (opts !== undefined) {
            prefix = opts.twprefix || "";
            if (opts.colors !== undefined) {
                colors = __assign(__assign({}, defaultColors), opts.colors);
            }
            else {
                colors = __assign({}, defaultColors);
            }
        }
        function addPrefix(className) {
            var parts = className.split(":");
            if (parts.length === 1) {
                return prefix + className;
            }
            else {
                return parts[0] + ":" + prefix + parts[1];
            }
        }
        var transformColor = memoize(function transformColor(className) {
            for (var _i = 0, COLOR_NAME_KEYS_1 = COLOR_NAME_KEYS; _i < COLOR_NAME_KEYS_1.length; _i++) {
                var colorName = COLOR_NAME_KEYS_1[_i];
                if (className.indexOf(colorName) !== -1) {
                    return className.replace(colorName, colors[colorName]);
                }
            }
            return className;
        });
        Vue$1.directive("twclass", {
            bind: function (el, binding, vnode) {
                var value = binding.value;
                if (typeof value === "string") {
                    for (var _i = 0, _a = value.split(/\s+/); _i < _a.length; _i++) {
                        var className = _a[_i];
                        if (className) {
                            el.classList.add(addPrefix(transformColor(className)));
                        }
                    }
                }
                else {
                    for (var className in value) {
                        if (value.hasOwnProperty(className) &&
                            value[className]) {
                            el.classList.add(addPrefix(transformColor(className)));
                        }
                    }
                }
            }
        });
    }
};

export default plugin;
